@@ -15,7 +15,7 @@ DEFAULT_NARROWPEAK_COLOR = '#FF000080'  # red, alpha=0.55
 class NarrowPeakTrack(BedGraphTrack):
     SUPPORTED_ENDINGS = ['.narrowPeak']
     TRACK_TYPE = 'narrow_peak'
-    OPTIONS_TXT = GenomeTrack.OPTIONS_TXT + """
+    OPTIONS_TXT = GenomeTrack.OPTIONS_TXT + f"""
 color = #FF000080
 #max_value = 0.70
 show_data_range = true
@@ -33,8 +33,8 @@ type = peak
 width_adjust = 1.5
 # optional: line_width
 #line_width = 0.5
-file_type = {}
-    """.format(TRACK_TYPE)
+file_type = {TRACK_TYPE}
+    """
     DEFAULTS_PROPERTIES = {'orientation': None,
                            'color': DEFAULT_NARROWPEAK_COLOR,
                            'max_value': None,
@@ -43,6 +43,7 @@ file_type = {}
                            'use_summit': True,
                            'width_adjust': 1.5,
                            'type': 'peak',
+                           'region': None,  # Cannot be set manually but is set by tracksClass
                            'line_width': 1}
     NECESSARY_PROPERTIES = ['file']
     SYNONYMOUS_PROPERTIES = {'max_value': {'auto': None}}
@@ -141,7 +142,7 @@ file_type = {}
             x_pos = start + float(end - start) / 2
             y_pos = 0 - max_signal * 0.05
             if self.properties['show_labels']:
-                ax.text(x_pos, y_pos, "{}\np-val:{:.1f}\nq-val:{:.1f}".format(name, p_value, q_value),
+                ax.text(x_pos, y_pos, f"{name}\np-val:{p_value:.1f}\nq-val:{q_value:.1f}",
                         horizontalalignment='center', size='smaller', verticalalignment='top')
 
         collection = PatchCollection(self.patches, facecolor=self.properties['color'], match_original=True)
@@ -186,7 +187,7 @@ file_type = {}
             if value % 1 == 0:
                 str_value = str(int(value))
             else:
-                str_value = "{:.1f}".format(value)
+                str_value = f"{value:.1f}"
             return str_value
 
         ymin, ymax = plot_axis.get_ylim()
